==> spip_3.0.8.orig.tar.xz: spip-3.0.8.orig/plugins-dist/petitions/lang/petitions_da.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'alerte_confirmer_suppression_signatures' => 'Vous allez supprimer toutes les signatures de cette p&eacute;tition. &Ecirc;tes-vous sur de vouloir continuer ?', # NEW
	'aucune_signature' => 'Aucune signature', # NEW

	// B
	'bouton_checkbox_envoi_message' => 'possibilit&eacute; d\'envoyer un message', # NEW
	'bouton_checkbox_indiquer_site' => 'indiquer obligatoirement un site web', # NEW
	'bouton_checkbox_signature_unique_email' => 'une seule signature par adresse email', # NEW
	'bouton_checkbox_signature_unique_site' => 'une seule signature par site web', # NEW

	// F
	'filtre' => 'Filtre :', # NEW
	'form_pet_adresse_site' => 'Dit websteds URL', # MODIF
	'form_pet_aucune_signature' => 'Ingen signatur svarer til denne kode...',
	'form_pet_confirmation' => 'Bekræft venligst din signatur:',
	'form_pet_deja_signe' => 'Du har allerede signeret denne tekst.',
	'form_pet_envoi_mail_confirmation' => 'En e-mail er netop sendt til dig som bekræftelse. Du bør gå ind på den URL, som er angivet i denne mail, for at bekræfte din signatur.', # MODIF
	'form_pet_mail_confirmation' => 'Goddag,

Du har ønsket at støtte denne appel:
@titre@.

Du at afgivet følgende oplysninger:
    Navn: @nom_email@
    Websted: @nom_site@ - @url_site@

VIGTIGT...
For at bekræfte din underskrift skal du blot klikke dig ind på
adressen nedenfor (ellers vil underskriften blive afvist):
    @url@

Tak for din deltagelse
', # MODIF
	'form_pet_message_commentaire' => 'Meddelelse eller kommentar?', # MODIF
	'form_pet_nom_site2' => 'Navn på dit websted', # MODIF
	'form_pet_probleme_liens' => 'Veuillez reprendre votre message en supprimant les liens hypertexte.', # NEW
	'form_pet_probleme_technique' => 'Teknisk problem: Appelfunktionen er i øjeblikket ude af drift.',
	'form_pet_signature_validee' => 'Din underskrift er godkendt. Den vil blive offentliggjort, når webstedet opdateres. Tak!',
	'form_pet_site_deja_enregistre' => 'Dette websted er allerede registreret',
	'form_pet_url_invalide' => 'Den URL, du har angivet, er ikke gyldig.',
	'form_pet_votre_email' => 'Din e-mail-adresse',
	'form_pet_votre_nom' => 'Dit navn eller alias', # MODIF
	'form_pet_votre_site' => 'Hvis du har et websted, kan du angive den nedenfor',

	// I
	'icone_relancer_signataire' => 'Relancer le signataire', # NEW
	'icone_relancer_signataires' => 'Relancer les signataires', # NEW
	'icone_suivi_petitions' => 'Suivre/g&eacute;rer les p&eacute;titions', # NEW
	'icone_supprimer_signature' => 'Supprimer cette signature', # NEW
	'icone_supprimer_signatures' => 'Supprimer les signatures', # NEW
	'icone_valider_signature' => 'Valider cette signature', # NEW
	'icone_valider_signatures' => 'Valider les signatures', # NEW
	'info_adresse_email' => 'EMAIL ADRESSE:',
	'info_fonctionnement_petition' => 'Fonctionnement de la p&eacute;tition :', # NEW
	'info_signature_supprimee' => 'Signature supprimée', # NEW
	'info_signature_supprimee_erreur' => 'Erreur : ce code de suppression ne correspond a aucune signature', # NEW
	'info_site_web' => 'WEBSTED:',
	'info_texte_message' => 'Meddelelsens tekst:',

	// L
	'lien_reponse_article' => 'Kommenter denne artikel',

	// N
	'nombre_signatures' => '@nb@ signatures', # NEW

	// S
	'sans_nom' => 'Anonyme', # NEW
	'signatures_article' => 'Signatures de l\'article :', # NEW
	'signatures_aucune' => 'Aucune', # NEW
	'signatures_meme_auteur' => 'Les signatures du m', # NEW
	'signatures_meme_site' => 'Les signatures avec le m', # NEW
	'signatures_poubelle' => 'Supprim&eacute;es', # NEW
	'signatures_prop' => 'En attente', # NEW
	'signatures_publie' => 'Confirm&eacute;es', # NEW
	'signatures_recherche_label' => 'Rechercher des signatures&nbsp;:', # NEW
	'signatures_toutes' => 'Toutes', # NEW
	'statut_poubelle' => 'Supprim&eacute;e', # NEW
	'statut_prop' => 'En attente de validation', # NEW
	'statut_publie' => 'Confirm&eacute;e', # NEW

	// T
	'texte_descriptif_petition' => 'Descriptif de la p&eacute;tition', # NEW
	'titre_page_controle_petition' => 'Suivi des p&eacute;titions', # NEW
	'titre_petition' => 'P&eacute;tition', # NEW
	'titre_petitions' => 'P&eacute;titions', # NEW
	'titre_selection_action' => 'Sélection', # NEW
	'titre_signatures_attente' => 'Signatures en attente de validation', # NEW
	'titre_signatures_publie' => 'Signatures confirm&eacute;es', # NEW
	'titre_suivi_petition' => 'Suivi des p&eacute;titions', # NEW
	'tout_voir' => 'Voir toutes les signatures', # NEW

	// U
	'une_signature' => '1 signature', # NEW

	// V
	'voir_signatures_objet' => 'Voir les signatures' # NEW
);

?>

==> spip_3.1~21100.orig.tar.xz: spip-3.1~21100.orig/plugins-dist/petitions/lang/petitions_da.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=da
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_activer_petition' => 'Tillad appeller',
	'bouton_radio_pas_petition' => 'Ingen appeller',
	'bouton_radio_petition_activee' => 'Appelfunktion slået til',
	'bouton_radio_supprimer_petition' => 'Slet appellen',

	// F
	'form_pet_adresse_site' => 'Dit websteds URL', # MODIF
	'form_pet_aucune_signature' => 'Ingen signatur svarer til denne kode...', # MODIF
	'form_pet_confirmation' => 'Bekræft venligst din signatur:',
	'form_pet_deja_signe' => 'Du har allerede signeret denne tekst.',
	'form_pet_envoi_mail_confirmation' => 'En e-mail er netop sendt til dig som bekræftelse. Du bør gå ind på den URL, som er angivet i denne mail, for at bekræfte din signatur.', # MODIF
	'form_pet_mail_confirmation' => 'Goddag,

Du har ønsket at støtte denne appel:
@titre@.

Du at afgivet følgende oplysninger:
    Navn: @nom_email@
    Websted: @nom_site@ - @url_site@

VIGTIGT...
For at bekræfte din underskrift skal du blot klikke dig ind på
adressen nedenfor (ellers vil underskriften blive afvist):
    @url@

Tak for din deltagelse
', # MODIF
	'form_pet_nom_site2' => 'Navn på dit websted', # MODIF
	'form_pet_probleme_technique' => 'Teknisk problem: Appelfunktionen er i øjeblikket ude af drift.',
	'form_pet_signature_validee' => 'Din underskrift er godkendt. Den vil blive offentliggjort, når webstedet opdateres. Tak!',
	'form_pet_site_deja_enregistre' => 'Dette websted er allerede registreret',
	'form_pet_url_invalide' => 'Den URL, du har angivet, er ikke gyldig.',
	'form_pet_votre_email' => 'Din e-mail-adresse',
	'form_pet_votre_nom' => 'Dit navn eller alias', # MODIF
	'form_pet_votre_site' => 'Hvis du har et websted, kan du angive den nedenfor',

	// I
	'info_adresse_email' => 'EMAIL ADRESSE:',
	'info_site_web' => 'WEBSTED:',

	// L
	'lien_reponse_article' => 'Kommenter denne artikel'
);

?>
